searchNodes=[{"doc":"NimblePublisher is a minimal filesystem-based publishing engine with Markdown support and code highlighting.use NimblePublisher, build: Article, from: &quot;articles/**/*.md&quot;, as: :articles, highlighters: [:makeup_elixir, :makeup_erlang]The example above will get all articles in the given directory, call Article.build/3 for each article, passing the filename, the metadata, and the article body, and define a module attribute named @articles with all built articles returned by the Article.build/3 function.Each article in the articles directory must have the format:%{ title: &quot;Hello world&quot; } --- Body of the &quot;Hello world&quot; article. This is a *markdown* document with support for code highlighters: ```elixir IO.puts &quot;hello world&quot;. ```Options:build - the name of the module that will build each entry:from - a wildcard pattern where to find all entries:as - the name of the module attribute to store all built entries:highlighters - which code highlighters to use. NimblePublisher uses Makeup for syntax highlighting and you will need to add its .css classes. You can generate the CSS classes by calling Makeup.stylesheet(:vim_style, &quot;makeup&quot;) inside iex -S mix. You can replace :vim_style by any style of your choice defined here.ExamplesLet's see a complete example. First add nimble_publisher with the desired highlighters as a dependency:def deps do [ {:nimble_publisher, &quot;~&gt; 0.1.0&quot;}, {:makeup_elixir, &quot;&gt;= 0.0.0&quot;}, {:makeup_erlang, &quot;&gt;= 0.0.0&quot;} ] endIn this example, we are building a blog. Each post stays in the &quot;posts&quot; directory with the format:/posts/YEAR/MONTH-DAY-ID.mdA typical blog post will look like this:# /posts/2020/04-17-hello-world.md %{ title: &quot;Hello world!&quot;, author: &quot;José Valim&quot;, tags: ~w(hello), description: &quot;Let&#39;s learn how to say hello world&quot; } --- This is the post.Therefore, we will define a Post struct that expects all of the fields above. We will also have a :date field that we will build from the filename. Overall, it will look like this:defmodule MyApp.Blog.Post do @enforce_keys [:id, :author, :title, :body, :description, :tags, :date] defstruct [:id, :author, :title, :body, :description, :tags, :date] def build(filename, attrs, body) do [year, month_day_id] = filename |&gt; Path.rootname() |&gt; Path.split() |&gt; Enum.take(-2) [month, day, id] = String.split(month_day_id, &quot;-&quot;, parts: 3) date = Date.from_iso8601!(&quot;\#{year}-\#{month}-\#{day}&quot;) struct!(__MODULE__, [id: id, date: date, body: body] ++ Map.to_list(attrs)) end endNow, we are ready to define our MyApp.Blog with NimblePublisher:defmodule MyApp.Blog do use NimblePublisher, build: Post, from: Application.app_dir(:my_app, &quot;posts/**/*.md&quot;), as: :posts, highlighters: [:makeup_elixir, :makeup_erlang] # The @posts variable is first defined by NimblePublisher. # Let&#39;s further modify it by sorting all posts by descending date. @posts Enum.sort_by(@posts, &amp; &amp;1.date, {:desc, Date}) # Let&#39;s also get all tags @tags @posts |&gt; Enum.flat_map(&amp; &amp;1.tags) |&gt; Enum.uniq() |&gt; Enum.sort() # And finally export them def all_posts, do: @posts def all_tags, do: @tags endImportant: Avoid injecting the @posts attribute into multiple functions, as each call will make a complete copy of all posts. For example, if you want to show define recent_posts() as well as all_posts(), DO NOT do this:def all_posts, do: @posts def recent_posts, do: Enum.take(@posts, 3)Instead do this:def all_posts, do: @posts def recent_posts, do: Enum.take(all_posts(), 3)Other helpersYou may want to define other helpers to traverse your published resources. For example, if you want to get posts by ID or with a given tag, you can define additional functions as shown below:defmodule NotFoundError do defexception [:message, plug_status: 404] end def get_post_by_id!(id) do Enum.find(all_posts(), &amp;(&amp;1.id == id)) || raise NotFoundError, &quot;post with id=\#{id} not found&quot; end def get_posts_by_tag!(tag) do case Enum.filter(all_posts(), &amp;(tag in &amp;1.tags)) do [] -&gt; raise NotFoundError, &quot;posts with tag=\#{tag} not found&quot; posts -&gt; posts end end","ref":"NimblePublisher.html","title":"NimblePublisher","type":"module"}]